@@ -24,7 +24,7 @@ use Storable qw(dclone);
 
 use DateTime::Format::Natural::Utils qw(trim);
 
-our $VERSION = '1.15';
+our $VERSION = '1.17';
 
 validation_options(
     on_fail => sub
@@ -76,8 +76,6 @@ sub _init
     $self->{data} = $mod->__new();
     $self->{grammar_class} = $mod;
 
-    $self->{format_provided} = exists $opts{format};
-
     $self->{mode} = '';
 }
 
@@ -359,6 +357,8 @@ sub parse_datetime_duration
         $shrinked = true;
     }
 
+    $self->_rewrite_duration(\@date_strings);
+
     $self->_pre_duration(\@date_strings);
     @$self{qw(state truncated_duration)} = ({}, []);
 
@@ -989,6 +989,7 @@ valuable suggestions and patches:
  Jrn Clausen
  Jim Avera
  Olaf Alders
+ Karen Etheridge
 
 =head1 SEE ALSO
 
